translate.storage.pocommon

Package translate :: Package storage :: Module pocommon |
[hide private]
[frames] | no frames]

# Module pocommon

source code

Classes | [hide private]
| pounit
| pofile

Functions | [hide private]
unicode |
extract_msgid_comment(text) The one definitive way to extract a msgid comment out of an unescaped unicode string that might contain it. | source code

Variables | [hide private]
| msgid_comment_re = `re.compile("_: (.*?)\n")`

Imports: base, poheader, re